---
author: Florent Gluck - Florent.Gluck@hesge.ch

title: Virtual Desktop Infrastructure (VDI) with Nexus

date: \vspace{.5cm} \footnotesize July 15, 2023

pandoc-latex-fontsize:
  - classes: [tiny]
    size: tiny
  - classes: [verysmall]
    size: scriptsize
  - classes: [small]
    size: footnotesize
  - classes: [huge, important]
    size: huge
---

[//]: # ----------------------------------------------------------------
## Local desktop infrastructure model

- Each user owns a computer on which an operating system (OS) is installed to run their applications
- **Local** model $\rightarrow$ everything runs on the user's machine

\vspace{.5cm}

\centering
![](images/client_pc.png){ width=30% }

[//]: # ----------------------------------------------------------------
## Virtual desktop infrastructure (VDI) model

::: incremental :::

- Each user has a virtual machine (VM) in which an OS is installed to run their applications
- Each user uses a "light" computer $\rightarrow$ used **only** to interact and display the desktop
- VMs **run** on a **remote** server hosted in a data center
- Desktop image transmitted over the network to the user's computer
- Usage **identical** to a local computer
- Remote model $\rightarrow$ **everything runs on the remote server

:::

[//]: # ----------------------------------------------------------------
## Virtual desktop example

\centering
![](images/VM_xubuntu_desktop.png){ width=95% }

[//]: # ----------------------------------------------------------------
## VDI architecture

\centering
![](images/vdi_arch.png){ width=90% }

[//]: # ----------------------------------------------------------------
## Nexus

::: incremental :::

Virtual desktop infrastructure (VDI) developed at ISC

- PC-based *live* exams **without the possibility of cheating**.
- **Personalized** environments for labs/exercises/practicals
- Usable by **any teacher**
- Virtual machines and access rights **highly configurable**
- Accessible from the **outside** via VPN
- **Secure** via encrypted communications

:::

[//]: # ----------------------------------------------------------------
## Nexus architecture

\centering
![](images/nexus_arch.png){ width=90% }

[//]: # ----------------------------------------------------------------
## Fraud-free exams with Nexus

\centering
![](images/exam_with_nexus.png){ width=90% }

[//]: # ----------------------------------------------------------------
## Exam preparation with Nexus

Before the exam (typically the day before), the teacher :

::: incremental :::

1. Prepares a VM *template* for the exam (exam questions + necessary software)
   - VM typically configured without Internet access (or only certain authorized sites)
1. Creates one VM per student
1. Starts student VMs
1. Generates unique accesses for each student on paper (1 paper strip/student)

:::

[//]: # ----------------------------------------------------------------
## Exam workflow with Nexus

:::::: {.columns}
::: {.column width="60%"}

The day of the exam :

::: incremental :::

\small

1. Teacher provides each student with a laptop\textsuperscript{*}
   - \footnotesize starts automatically on Nexus-exam via wired network (or HES-GE wifi) or dedicated USB key
1. Teacher provides each student with credentials (paper)
1. Student logs into their VM using their credentials and does the exam
1. Student shuts down their VM once the exam is completed

:::

:::
::: {.column width="40%"}

\centering
![](images/nexus-exam.png){ width=100% }

\vspace{.5cm}

\centering
![](images/vmcred2pdf.png){ width=100% }

:::
::::::

\vfill
\textsuperscript{*}\scriptsize variante : possibilité d'utiliser le laptop de l'étudiant-e

[//]: # ----------------------------------------------------------------
## Exam grading with Nexus

When the teacher is ready to grade the exams :

::: incremental :::

1. Uploads student-generated files from each VM to their PC
1. Grade the work produced
   - can also use the student's VM to test what the student produced
1. Deletes all students' VMs

:::

[//]: # ----------------------------------------------------------------
## Nexus demo

![](images/demo_time.png){ height=100% }


[//]: # ----------------------------------------------------------------
## Assessment so far

- Nexus is being used **\textcolor{mygreen}{with great success}** for *live* exams at ISC since October 2022

\vspace{.5cm}

\centering
![](images/thumb_up.png){ width=50% }

[//]: # ----------------------------------------------------------------
## Nexus resource usage

\footnotesize
Use case below: 45 VMs (2 vCPUs, 3.5GB RAM)

![](images/resources_usage_45vms_2vcpus_3500ram.png){ width=100% }


[//]: # ----------------------------------------------------------------
## Future improvements

- New functionalities
  - graphical user interface
  - virtual network management
  - Windows VM
  - ...
- Used in other HEPIA departments?
- Funding application as part of a digital teaching project (HES-SO digital strategy)

[//]: # ----------------------------------------------------------------
## Questions

\centering
![](images/questions.png){ width=80% }
