package qga

import (
    "fmt"
    "net"
    "errors"
    "encoding/base64"
    "nexus-server/logger"
)

type QGACon struct {
    sock net.Conn
}

var log = logger.GetInstance()

func New() *QGACon {
    return &QGACon{}
}

// TODO
// Rewrite most of this code to use a json serializer
// instead of this ugly-dirty "json as string" code!

// sockAddr is the path to a UNIX domain socket.
func (q *QGACon)Open(sockAddr string) error {
    con, err := net.Dial("unix", sockAddr)
    if err != nil {
        return err
    }
    q.sock = con
    return nil
}

func (q *QGACon)Close() error {
    return q.sock.Close()
}

// Send a shutdown command to the guest OS.
func (q *QGACon)SendShutdown() error {
    _, err := q.sock.Write([]byte(`
    {
        "execute": "guest-shutdown"
    }
    `))
    return err
}

// Send a reboot command to the guest OS.
func (q *QGACon)SendReboot() error {
    return q.SendCmd("reboot")
}

// Send a forced reboot command to the guest OS.
func (q *QGACon)SendForcedReboot() error {
    _, err := q.sock.Write([]byte(`
    {
        "execute":"guest-exec",
        "arguments": {
            "path":"reboot",
            "arg": ["--force"]
        }
    }
    `))
    return err
}

// Send a command to the guest OS.
func (q *QGACon)SendCmd(cmd string) error {
    _, err := q.sock.Write([]byte(`
    {
        "execute":"guest-exec",
        "arguments": {
            "path":"`+cmd+`"
        }
    }
    `))
    return err
}

// TODO: work in progress...
func (q *QGACon)WriteFile(filePath string) error {
    filePath = "/home/nexus/pipo.txt"
    _, err := q.sock.Write([]byte(`
    {
        "execute":"guest-file-open",
        "arguments": {
            "path":"`+filePath+`",
            "mode":"w+"
        }
    }
    `))
    buf := make([]byte, 128)
    _, err = q.sock.Read(buf)
    if err != nil {
        return err
    }
    handle := string(buf[:])
    fmt.Println("handle: ",handle)

    // content must be encoded in base64
    content := "Hello ma poule!"
    contentB64 := base64.StdEncoding.EncodeToString([]byte(content))
    status, err := q.sock.Write([]byte(`
    {
        "execute":"guest-file-write",
        "arguments": {
            "handle":1000,
            "buf-b64":"`+contentB64+`"
        }
    }
    `))
    status, err = q.sock.Write([]byte(`
    {
        "execute":"guest-file-close",
        "arguments": {
            "handle":1000
        }
    }
    `))
    if status < 0 {
        return errors.New("write error")
    }
    return err
}
